@@ -11,8 +11,7 @@ from operator import eq
 import tqdm
 from typing import List
 import math
-# from plot3d_point_match import plot3d_point_match
-from .module.plot3d_point_match import plot3d_point_match
+from point_match import point_match
 
 def get_outer_faces(block1:Block):
     """Get the outer faces of a block
